from django.db import models
from django.urls import reverse
from django.core.validators import RegexValidator, MaxValueValidator

# Create your models here.

class Author(models.Model):
    first_name = models.CharField(default="", max_length=100)
    last_name = models.CharField(default="", max_length=100)
    age = models.PositiveIntegerField(default=0)
    nationality = models.CharField(default="", max_length=100)
    bio = models.TextField(default="", max_length = 700)

    def __str__(self):
        return '{} {}'.format(self.first_name, self.last_name)

    def get_absolute_url(self):
        return reverse('bookshelf:author-detail', kwargs={'pk' : self.pk})

class Book(models.Model):
    title = models.CharField(default="", max_length=100)
    author = models.ForeignKey(Author, on_delete=models.CASCADE)
    publisher = models.CharField(default="", max_length=100)
    ISBN = models.PositiveIntegerField(validators=
        [RegexValidator(r'^[0-9]*$', 
        message='Only numbers are allowed'),
        MaxValueValidator(9999999999999, message="Ensure this value has 13 digits")])
    blurb = models.TextField(default="", max_length = 700)

    def __str__(self):
        return '{}'.format(self.title)

    def get_absolute_url(self):
        return reverse('bookshelf:books-detail', kwargs={'pk' : self.pk})
